(***********************************************************************)
(*                                                                     *)
(*                               Grimage                               *)
(*                                                                     *)
(*                           Graphics image                            *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2014-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: grimage.ml,v 1.10 2014/02/27 16:45:22 fclement Exp $ *)

(** Interface of images from this library with images of the Caml
    [Graphics] library. *)

type grimage = Generic_image.image;;
type t = grimage;;

let grimage_of_pixmap = Pixmap.generic_image_of_pixmap;;
let pixmap_of_grimage = Pixmap.pixmap_of_generic_image;;

let grimage_of_image = Pixmap.generic_image_of_image;;
let image_of_grimage = Pixmap.image_of_generic_image;;

let load_ppm_grimage = Ppm.load_generic_image;;
let load_bmp_grimage = Bmp.load_generic_image;;

let save_ppm_grimage = Ppm.save_generic_image;;
let save_bmp_grimage = Bmp.save_generic_image;;

let draw_bmp img = Graphics.draw_image (Bmp.image_of_bmp img);;
let draw_ppm img = Graphics.draw_image (Ppm.image_of_ppm img);;

let draw_grimage img x y = Graphics.draw_image (image_of_grimage img) x y;;
let draw_bmp_file fname = draw_grimage (load_bmp_grimage fname);;
let draw_ppm_file fname = draw_grimage (load_ppm_grimage fname);;

let image_of_screen () =
  Graphics.get_image 0 0 (Graphics.size_x ()) (Graphics.size_y ())
;;

let screen_of_image img =
  Graphics.draw_image img 0 0
;;

let save_screen_bmp fname =
  Bmp.save_image fname (image_of_screen ())
;;

let save_screen_ppm fname =
  Ppm.save_image fname (image_of_screen ())
;;

let restore_screen_bmp fname = draw_bmp_file fname 0 0;;

let restore_screen_ppm fname = draw_ppm_file fname 0 0;;
