(***********************************************************************)
(*                                                                     *)
(*                              Ref-image                              *)
(*                                                                     *)
(*                  Image Segmentation by Refinement                   *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2009-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: umatrix_graph.mli,v 1.6 2014-01-21 17:17:21 fclement Exp $ *)

(** {3 Matrix graphs of function} *)

type index = Umatrix_nonempty_set.index
and uindex = Umatrix_nonempty_set.uindex
;;

type domain = Umatrix_nonempty_set.t;;

type sub_domain = Umatrix_nonempty_set.nonempty_subset;;

type 'a images =
  | Constant of 'a
  | Images of 'a array
;;

type 'a t = private
  {
   domain : domain;
   images : 'a images;
  }
;;

val same : 'a t -> 'a t -> bool;;

(** {6 Construction functions} *)

val make : 'a Umatrix.t -> 'a t;;

val constant : domain -> 'a -> 'a t;;
val from_array : domain -> 'a array -> 'a t;;
val from_fun : domain -> (index -> uindex -> 'a) -> 'a t;;

(** {6 Access functions} *)

val get_constant : 'a t -> 'a;;

val image : 'a t -> index -> 'a;;

val restriction : 'a t -> sub_domain -> 'a t;;

(** {6 Iterators} *)

val map_images : ('a -> 'b) -> 'a t -> 'b t;;
