(***********************************************************************)
(*                                                                     *)
(*                              Ref-image                              *)
(*                                                                     *)
(*                  Image Segmentation by Refinement                   *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2009-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: history_spec.mli,v 1.21 2014-01-21 17:17:22 fclement Exp $ *)

open History_types;;

module type CONFIGURATION =
sig
  (*val digest : configuration Utype_digest.t;;*)
  
  val print : Configuration_types.t Format_printer.printer;;
  
  val cold_set : unit -> unit;;
  val warm_set : Configuration_types.t -> unit;;
  val get : unit -> Configuration_types.t;;
end
;;

module type STATE =
sig
  type t;;
  
  (*val digest : state Utype_digest.t;;*)
  
  val same : t -> t -> bool;;
  val print : t Format_printer.printer;;
  
  val init : unit -> t;;
  val final : Ufilename.t -> t -> unit;;
end
;;

(* Todo: Use polymorphic MD5's for type signatures.

type 'a digest = string = Digest.t;;

val save_history : 'a digest -> 'b digest -> Ufilename.t -> ('a, 'b) t -> unit;;
val restore_history : 'a digest -> 'b digest -> Ufilename.t -> ('a, 'b) t;;

restore_history must check in its filename argument the presence of the
correct 'a digest and 'b digest string digests.
save_history must save the digest of ``history_types.cmi'', and restore_history
must check it. *)

module type HISTORY =
sig
  type state;;
  
  type t = (Configuration_types.t, state) History_types.t;;
  
  (*val digest : t Utype_digest.t;;*)
  
  val make_history_step : state_number -> state -> t -> t;;
  
  val head_state : t -> state;;
  val head_state_number : t -> state_number;;
  
  val same_head_state : t -> t -> bool;;
  
  val print : t Format_printer.printer;;
  val print_head_h_state : t Format_printer.printer;;
  
  val initialization : unit -> t;;
  val finalization : t -> unit;;
end
;;

module type HISTORY_MAKER =
  functor (C : CONFIGURATION) ->
  functor (St : STATE) ->
  HISTORY with type state = St.t
;;
