(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2004-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* Beginning of OCamlGen, 3.3+dev4 generated code *)

let print_xml_purpose ppf = function
  | Udebug.User -> Format.fprintf ppf "%s" "<User/>"
  | Udebug.Library -> Format.fprintf ppf "%s" "<Library/>"

and print_xml_software_name ppf = function
  | s -> Lib_print_xml.print_xml_quoted_string ppf s
;;

let rec print_xml_short_key_prefix ppf = function
  | Udebug.Automatic -> Format.fprintf ppf "%s" "<Automatic/>"
  | Udebug.Short u_p ->
    Format.fprintf ppf "@[<1>%s@," "<Short>";
    Upervasives_print_xml.print_xml_prefix ppf u_p;
    Format.fprintf ppf "%,</Short>"; Format.fprintf ppf "%,@]"

and print_xml_key_prefixes ppf = function
  | { Udebug.long = u_p; Udebug.short = s; } ->
    Format.fprintf ppf "%,@[<1>{@,";
    Upervasives_print_xml.print_xml_prefix ppf u_p; Format.fprintf ppf "%,;";
    print_xml_short_key_prefix ppf s; Format.fprintf ppf "%,;";
    Format.fprintf ppf "%,@,}@]"
;;

let rec print_xml_print px_a ppf = function
  | f_a_u ->
    Lib_print_xml.print_xml_fun px_a Lib_print_xml.print_xml_unit ppf f_a_u

and print_xml_fun_name_print px_a ppf = function
  | f_u_f_a_p ->
    Lib_print_xml.print_xml_fun Upervasives_print_xml.print_xml_function_name
     (print_xml_print px_a) ppf f_u_f_a_p
;;

let print_xml_printing_facilities ppf = function
  | {
      Udebug.report = u_m_p;
      Udebug.debug = u_m_f;
      Udebug.warning = u_m_f0;
      Udebug.error = u_m_f1;
      Udebug.report_action = u_g_p;
      Udebug.debug_action = u_g_f;
      Udebug.warning_action = u_g_f0;
      Udebug.error_action = u_g_f1;
    } ->
    Format.fprintf ppf "%,@[<1>{@,";
    print_xml_print Upervasives_print_xml.print_xml_message ppf u_m_p;
    Format.fprintf ppf "%,;";
    print_xml_fun_name_print Upervasives_print_xml.print_xml_message ppf
     u_m_f;
    Format.fprintf ppf "%,;";
    print_xml_fun_name_print Upervasives_print_xml.print_xml_message ppf
     u_m_f0;
    Format.fprintf ppf "%,;";
    print_xml_fun_name_print Upervasives_print_xml.print_xml_message ppf
     u_m_f1;
    Format.fprintf ppf "%,;";
    print_xml_print Upervasives_print_xml.print_xml_gen_message ppf u_g_p;
    Format.fprintf ppf "%,;";
    print_xml_fun_name_print Upervasives_print_xml.print_xml_gen_message ppf
     u_g_f;
    Format.fprintf ppf "%,;";
    print_xml_fun_name_print Upervasives_print_xml.print_xml_gen_message ppf
     u_g_f0;
    Format.fprintf ppf "%,;";
    print_xml_fun_name_print Upervasives_print_xml.print_xml_gen_message ppf
     u_g_f1;
    Format.fprintf ppf "%,;"; Format.fprintf ppf "%,@,}@]"
;;

let rec print_xml_tag ppf = function
  | s -> Lib_print_xml.print_xml_quoted_string ppf s

and print_xml_make_tag px_a ppf = function
  | f_a_t -> Lib_print_xml.print_xml_fun px_a print_xml_tag ppf f_a_t
;;

let print_xml_dynamic_printing_facilities px_a ppf = function
  | {
      Udebug.dyn_report = f_a_u_m_p;
      Udebug.dyn_debug = f_a_u_m_f;
      Udebug.dyn_warning = f_a_u_m_f0;
      Udebug.dyn_error = f_a_u_m_f1;
      Udebug.dyn_report_action = f_a_u_g_p;
      Udebug.dyn_debug_action = f_a_u_g_f;
      Udebug.dyn_warning_action = f_a_u_g_f0;
      Udebug.dyn_error_action = f_a_u_g_f1;
    } ->
    Format.fprintf ppf "%,@[<1>{@,";
    Lib_print_xml.print_xml_fun px_a
     (print_xml_print Upervasives_print_xml.print_xml_message) ppf f_a_u_m_p;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun px_a
     (print_xml_fun_name_print Upervasives_print_xml.print_xml_message) ppf
     f_a_u_m_f;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun px_a
     (print_xml_fun_name_print Upervasives_print_xml.print_xml_message) ppf
     f_a_u_m_f0;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun px_a
     (print_xml_fun_name_print Upervasives_print_xml.print_xml_message) ppf
     f_a_u_m_f1;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun px_a
     (print_xml_print Upervasives_print_xml.print_xml_gen_message) ppf
     f_a_u_g_p;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun px_a
     (print_xml_fun_name_print Upervasives_print_xml.print_xml_gen_message)
     ppf f_a_u_g_f;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun px_a
     (print_xml_fun_name_print Upervasives_print_xml.print_xml_gen_message)
     ppf f_a_u_g_f0;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun px_a
     (print_xml_fun_name_print Upervasives_print_xml.print_xml_gen_message)
     ppf f_a_u_g_f1;
    Format.fprintf ppf "%,;"; Format.fprintf ppf "%,@,}@]"
;;

let print_xml_specialized_printing_facilities ppf = function
  | {
      Udebug.spf_report = u_m_p;
      Udebug.spf_debug = u_m_p0;
      Udebug.spf_warning = u_m_p1;
      Udebug.spf_error = u_m_p2;
      Udebug.spf_report_action = u_g_p;
      Udebug.spf_debug_action = u_g_p0;
      Udebug.spf_warning_action = u_g_p1;
      Udebug.spf_error_action = u_g_p2;
    } ->
    Format.fprintf ppf "%,@[<1>{@,";
    print_xml_print Upervasives_print_xml.print_xml_message ppf u_m_p;
    Format.fprintf ppf "%,;";
    print_xml_print Upervasives_print_xml.print_xml_message ppf u_m_p0;
    Format.fprintf ppf "%,;";
    print_xml_print Upervasives_print_xml.print_xml_message ppf u_m_p1;
    Format.fprintf ppf "%,;";
    print_xml_print Upervasives_print_xml.print_xml_message ppf u_m_p2;
    Format.fprintf ppf "%,;";
    print_xml_print Upervasives_print_xml.print_xml_gen_message ppf u_g_p;
    Format.fprintf ppf "%,;";
    print_xml_print Upervasives_print_xml.print_xml_gen_message ppf u_g_p0;
    Format.fprintf ppf "%,;";
    print_xml_print Upervasives_print_xml.print_xml_gen_message ppf u_g_p1;
    Format.fprintf ppf "%,;";
    print_xml_print Upervasives_print_xml.print_xml_gen_message ppf u_g_p2;
    Format.fprintf ppf "%,;"; Format.fprintf ppf "%,@,}@]"
;;

let print_xml_specialized_dynamic_printing_facilities px_a ppf = function
  | {
      Udebug.sdpf_report = f_a_u_m_p;
      Udebug.sdpf_debug = f_a_u_m_p0;
      Udebug.sdpf_warning = f_a_u_m_p1;
      Udebug.sdpf_error = f_a_u_m_p2;
      Udebug.sdpf_report_action = f_a_u_g_p;
      Udebug.sdpf_debug_action = f_a_u_g_p0;
      Udebug.sdpf_warning_action = f_a_u_g_p1;
      Udebug.sdpf_error_action = f_a_u_g_p2;
    } ->
    Format.fprintf ppf "%,@[<1>{@,";
    Lib_print_xml.print_xml_fun px_a
     (print_xml_print Upervasives_print_xml.print_xml_message) ppf f_a_u_m_p;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun px_a
     (print_xml_print Upervasives_print_xml.print_xml_message) ppf f_a_u_m_p0;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun px_a
     (print_xml_print Upervasives_print_xml.print_xml_message) ppf f_a_u_m_p1;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun px_a
     (print_xml_print Upervasives_print_xml.print_xml_message) ppf f_a_u_m_p2;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun px_a
     (print_xml_print Upervasives_print_xml.print_xml_gen_message) ppf
     f_a_u_g_p;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun px_a
     (print_xml_print Upervasives_print_xml.print_xml_gen_message) ppf
     f_a_u_g_p0;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun px_a
     (print_xml_print Upervasives_print_xml.print_xml_gen_message) ppf
     f_a_u_g_p1;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun px_a
     (print_xml_print Upervasives_print_xml.print_xml_gen_message) ppf
     f_a_u_g_p2;
    Format.fprintf ppf "%,;"; Format.fprintf ppf "%,@,}@]"
;;

(* End of OCamlGen, 3.3+dev4 generated code *)
