(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2004-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: ublockmatrix.mli,v 1.11 2014/01/10 15:28:04 fclement Exp $ *)

(** {3 Block matrix operations} *)

type 'a block_matrix = 'a Umatrix.t Umatrix.t;;
type 'a t = 'a block_matrix;;
(** The type of block matrices.
   A block matrix is a two-dimensional array of matrices. *)

val size : 'a block_matrix -> Unatural.t * Unatural.t;;
(** Return the size of the given block matrix.
    The size of a block matrix is a pair of integers that gives the number
    of blocks in both directions. *)

val length : 'a block_matrix -> Unatural.t * Unatural.t;;
(** [length] is an alias for {!size}. *)

(*val sizes : 'a block_matrix -> Unatural.t array * Unatural.t array;;
(** Return the sizes (pair of arrays of numbers of elements in both directions)
   of the given block matrix. *)

val lengths : 'a block_matrix -> Unatural.t array * Unatural.t array;;
(** [lengths] is an alias for {!sizes}. *)

val to_matrix : 'a block_matrix -> 'a Umatrix.t;;
(** *)

val of_matrix :
  'a Umatrix.t -> Unatural.t array -> Unatural.t array -> 'a block_matrix;;
(** *)
*)

val resize : Unatural.t -> Unatural.t -> 'a block_matrix -> 'a block_matrix;;
(** [resize ni nj m] returns a fresh matrix of size [(ni, nj)].
   Each element of the given matrix [m] becomes a submatrix of size

   Raise [Invalid_arg] if the matrix [m] has a zero dimension and not... . *)

val zoom : Unatural.t -> Unatural.t -> 'a block_matrix -> 'a block_matrix;;
(** [zoom ni nj m] returns a fresh matrix whose dimensions are
   those of [m] multiplied by [ni] and [nj]. Each element of the given matrix
   [m] becomes a submatrix of size [(ni, nj)]. *)
