(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2004-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: uunix.mli,v 1.19 2014/02/09 14:38:23 fclement Exp $ *)

(** {3 More Unix operations} *)

val spawn_init :
  (Scanf.Scanning.scanbuf * out_channel -> unit) ->
  string -> Scanf.Scanning.scanbuf option ref -> out_channel option ref ->
  Scanf.Scanning.scanbuf * out_channel
;;
(** [spawn_init init_cmd cmd bin cout] spawns command [cmd] and execute
 [init_cmd], if it has not yet been launched.
 More precisely, if the contents of references [bin] or [cout] is [None] then:
 - the command [cname] is launched,
 - an input buffer to its [stdin] is assigned to [cin],
 - an output channel to its [stdout] is assigned to [cout],
 - execute initialize command [init_cmd].
 Nothing happens if the contents of references [bin] and [cout]
 are not [None]. *)

type command_line = string;;

type process_io_buffers =
  {
   input_buffer : Scanf.Scanning.scanbuf;
   output_buffer : Buffer.t;
   flush_output : unit -> unit;
  }
;;

val spawn :
  Udebug.specialized_printing_facilities ->
  command_line -> process_io_buffers option ref -> process_io_buffers
;;
(** [spawn pf cname bin cout] spawns command [cname], if it has not yet been
  launched. More precisely, if the contents of references [bin] or [cout]
  is [None] then:
  - the command [cname] is launched,
  - an input buffer to its [stdin] is assigned to [cin],
  - an output channel to its [stdout] is assigned to [cout].
  Nothing happens if the contents of references [bin] and [cout]
  are not [None]. *)

val std_process_io_buffers : process_io_buffers;;

type pid = int;;

val launch_connected_processes :
  string -> string list -> string -> string list -> pid * pid
;;
(** [launch_connected_processes prog1 args1 prog2 args2] launches
  [prog1 args1] and [prog2 args2] with each other reading and writing to the
  corresponding [stdout]/[stdin] of the other program
  and returns their pids. *)

val launch_connected_processes_with_err_on_channels :
  string -> string list -> out_channel ->
  string -> string list -> out_channel -> pid * pid
;;
(** Same as above with the redirection of the standard error of each process
  to the corresponding [out_channel]. *)

val wait_for_normal_termination : pid -> unit
;;
(** Wait for normal termination of process of given [pid].
  In case of abnormal termination of process [pid], a relevant message is
  written on stderr and the function exits with nonzero error code. *)
